searchData={"items":[{"type":"module","title":"Enumx","doc":"","ref":"Enumx.html"},{"type":"function","title":"Enumx.all_equal?/1","doc":"Returns `true` if all elements in `enumerable` are equal.","ref":"Enumx.html#all_equal?/1"},{"type":"function","title":"Enumx.filter_value/2","doc":"Similar to filter/2, but returns the value of the function invocation instead of the element itself","ref":"Enumx.html#filter_value/2"},{"type":"function","title":"Enumx.unique_value!/1","doc":"Returns the single unique element if all elements in enumerable are equal; otherwise, raises an error.","ref":"Enumx.html#unique_value!/1"},{"type":"function","title":"Enumx.with_index_length/2","doc":"Returns tuples of each element, its index, and the total length of the enumerable.","ref":"Enumx.html#with_index_length/2"},{"type":"extras","title":"Enumx","doc":"# Enumx\n\nAdditional utility functions to extend the power of Elixir's Enum module.\n\n## `filter_value/2`\n\nSimilar to `filter/2`, but returns the value of the function invocation instead of the element itself.\n\n```elixir\nassert Enumx.filter_value([1, 2, 3, 4, 5], &(&1 > 3 && &1 * 2)) == [8, 10]\n\nassert Enumx.filter_value([foo: 1, bar: 2, baz: 3], fn {k, v} -> v > 1 && k end) == [:bar, :baz]\n\nassert Enumx.filter_value(%{foo: 1, bar: 2, baz: 3}, fn {k, v} -> v > 1 && k end) == [:bar, :baz]\n```\n\n## `all_equal?/1`\n\nReturns `true` if all elements in `enumerable` are equal.\n\n```elixir\nassert Enumx.all_equal?([1, 1])\n\nassert Enumx.all_equal?([foo: 1, foo: 1])\n```\n\n## `unique_value!/1`\n\nReturns the single unique element if all elements in enumerable are equal; otherwise, raises an error.\n\n```elixir\nassert Enumx.unique_value!([1, 1]) == 1\n\nassert Enumx.unique_value!(%{foo: 1}) == {:foo, 1}\n\nassert Enumx.unique_value!([foo: 1, foo: 1]) == {:foo, 1}\n\nassert_raise ArgumentError, fn ->\n  Enumx.unique_value!([]) # raises error: cannot call `unique_value!/1` on an empty list\nend\n\nassert_raise RuntimeError, fn ->\n  Enumx.unique_value!([1, 2]) # raises error: elements in the list [1, 2] are not equal\nend\n```\n\n## `with_index_length/2`\n\nReturns tuples of each element, its index, and the total length of the enumerable.\n\n```elixir\nassert [{3, 0, :foo}, {3, 1, :bar}, {3, 2, :baz}] ==\n          Enumx.with_index_length([:foo, :bar, :baz], fn el, i, length -> {length, i, el} end)\n\nassert [{:foo, 5, 3}, {:bar, 6, 3}, {:baz, 7, 3}] == \n          Enumx.with_index_length([:foo, :bar, :baz], 5)\n```","ref":"readme.html"},{"type":"extras","title":"Installation - Enumx","doc":"Add `enumx` for Elixir as a dependency in your `mix.exs` file:\n\n```elixir\ndef deps do\n  [\n    {:enumx, \"~> 0.3\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"HexDocs - Enumx","doc":"HexDocs documentation can be found at [https://hexdocs.pm/enumx](https://hexdocs.pm/enumx).","ref":"readme.html#hexdocs"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}